@@ -5,4 +5,21 @@
 #'
 #' @docType package
 #' @name IBCF.MTME
-NULL
\ No newline at end of file
+NULL
+
+if (getRversion() >= "2.15.1")
+  utils::globalVariables(
+    c('.',
+      'Environment',
+      'Trait',
+      'Partition',
+      'Predicted',
+      'Observed',
+      'Pearson',
+      'MAAPE',
+      'SE_Pearson',
+      'SE_MAAPE',
+      'n'
+    )
+
+  )
\ No newline at end of file
